abacusai.pipeline_step_version_logs — AbacusAI documentation

# `abacusai.pipeline_step_version_logs`

## Module Contents

### Classes

`PipelineStepVersionLogs` | Logs for a given pipeline step version.

class abacusai.pipeline_step_version_logs.PipelineStepVersionLogs(client, stepName=None, pipelineStepId=None, pipelineStepVersion=None, logs=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Logs for a given pipeline step version.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - stepName (str) – The name of the step

    - pipelineStepId (str) – The ID of the step

    - pipelineStepVersion (str) – The version of the step

    - logs (str) – The logs for both stdout and stderr of the step

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict